==> DateTime-Locale-1.17.tar.gz: DateTime-Locale-1.17/share/fo.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d.",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d. MMM y G",
    GyMMMd => "d. MMM y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "LL",
    MEd => "E dd.MM",
    MMM => "LLL",
    MMMEd => "E d. MMM",
    "MMMMW-count-one" => "W. 'vika' '\N{U+00ed}' MMM",
    "MMMMW-count-other" => "W. 'vika' '\N{U+00ed}' MMM",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    Md => "dd.MM",
    d => "d.",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM.y",
    yMEd => "E dd.MM.y",
    yMMM => "MMM y",
    yMMMEd => "E d. MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d. MMM y",
    yMd => "dd.MM.y",
    yQQQ => "QQQ '\N{U+00ed}' y",
    yQQQQ => "QQQQ '\N{U+00ed}' y",
    "yw-count-one" => "w. 'vika' '\N{U+00ed}' Y",
    "yw-count-other" => "w. 'vika' '\N{U+00ed}' Y",
  },
  code => "fo",
  date_format_full => "EEEE, d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "dd.MM.y",
  date_format_short => "dd.MM.yy",
  datetime_format_full => "{1} 'kl'. {0}",
  datetime_format_long => "{1} 'kl'. {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "m\N{U+00e1}n.",
    "t\N{U+00fd}s.",
    "mik.",
    "h\N{U+00f3}s.",
    "fr\N{U+00ed}.",
    "ley.",
    "sun.",
  ],
  day_format_narrow => [
    "M",
    "T",
    "M",
    "H",
    "F",
    "L",
    "S",
  ],
  day_format_wide => [
    "m\N{U+00e1}nadagur",
    "t\N{U+00fd}sdagur",
    "mikudagur",
    "h\N{U+00f3}sdagur",
    "fr\N{U+00ed}ggjadagur",
    "leygardagur",
    "sunnudagur",
  ],
  day_stand_alone_abbreviated => [
    "m\N{U+00e1}n",
    "t\N{U+00fd}s",
    "mik",
    "h\N{U+00f3}s",
    "fr\N{U+00ed}",
    "ley",
    "sun",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "M",
    "H",
    "F",
    "L",
    "S",
  ],
  day_stand_alone_wide => [
    "m\N{U+00e1}nadagur",
    "t\N{U+00fd}sdagur",
    "mikudagur",
    "h\N{U+00f3}sdagur",
    "fr\N{U+00ed}ggjadagur",
    "leygardagur",
    "sunnudagur",
  ],
  era_abbreviated => [
    "f.Kr.",
    "e.Kr.",
  ],
  era_narrow => [
    "fKr",
    "eKr",
  ],
  era_wide => [
    "fyri Krist",
    "eftir Krist",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Faroese",
  month_format_abbreviated => [
    "jan.",
    "feb.",
    "mar.",
    "apr.",
    "mai",
    "jun.",
    "jul.",
    "aug.",
    "sep.",
    "okt.",
    "nov.",
    "des.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "januar",
    "februar",
    "mars",
    "apr\N{U+00ed}l",
    "mai",
    "juni",
    "juli",
    "august",
    "september",
    "oktober",
    "november",
    "desember",
  ],
  month_stand_alone_abbreviated => [
    "jan",
    "feb",
    "mar",
    "apr",
    "mai",
    "jun",
    "jul",
    "aug",
    "sep",
    "okt",
    "nov",
    "des",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "januar",
    "februar",
    "mars",
    "apr\N{U+00ed}l",
    "mai",
    "juni",
    "juli",
    "august",
    "september",
    "oktober",
    "november",
    "desember",
  ],
  name => "Faroese",
  native_language => "f\N{U+00f8}royskt",
  native_name => "f\N{U+00f8}royskt",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "1. \N{U+00e1}rsfj.",
    "2. \N{U+00e1}rsfj.",
    "3. \N{U+00e1}rsfj.",
    "4. \N{U+00e1}rsfj.",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. \N{U+00e1}rsfj\N{U+00f3}r\N{U+00f0}ingur",
    "2. \N{U+00e1}rsfj\N{U+00f3}r\N{U+00f0}ingur",
    "3. \N{U+00e1}rsfj\N{U+00f3}r\N{U+00f0}ingur",
    "4. \N{U+00e1}rsfj\N{U+00f3}r\N{U+00f0}ingur",
  ],
  quarter_stand_alone_abbreviated => [
    "1. \N{U+00e1}rsfj.",
    "2. \N{U+00e1}rsfj.",
    "3. \N{U+00e1}rsfj.",
    "4. \N{U+00e1}rsfj.",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. \N{U+00e1}rsfj\N{U+00f3}r\N{U+00f0}ingur",
    "2. \N{U+00e1}rsfj\N{U+00f3}r\N{U+00f0}ingur",
    "3. \N{U+00e1}rsfj\N{U+00f3}r\N{U+00f0}ingur",
    "4. \N{U+00e1}rsfj\N{U+00f3}r\N{U+00f0}ingur",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 32,
}

==> DateTime-Locale-1.27.tar.gz: DateTime-Locale-1.27/share/fo.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d.",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d. MMM y G",
    GyMMMd => "d. MMM y G",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "LL",
    MEd => "E dd.MM",
    MMM => "LLL",
    MMMEd => "E d. MMM",
    "MMMMW-count-one" => "W. 'vika' '\N{U+00ed}' MMMM",
    "MMMMW-count-other" => "W. 'vika' '\N{U+00ed}' MMMM",
    MMMMd => "d. MMMM",
    MMMd => "d. MMM",
    Md => "dd.MM",
    d => "d.",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "MM.y",
    yMEd => "E dd.MM.y",
    yMMM => "MMM y",
    yMMMEd => "E d. MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d. MMM y",
    yMd => "dd.MM.y",
    yQQQ => "QQQ '\N{U+00ed}' y",
    yQQQQ => "QQQQ '\N{U+00ed}' y",
    "yw-count-one" => "w. 'vika' '\N{U+00ed}' Y",
    "yw-count-other" => "w. 'vika' '\N{U+00ed}' Y",
  },
  code => "fo",
  date_format_full => "EEEE, d. MMMM y",
  date_format_long => "d. MMMM y",
  date_format_medium => "dd.MM.y",
  date_format_short => "dd.MM.yy",
  datetime_format_full => "{1} 'kl'. {0}",
  datetime_format_long => "{1} 'kl'. {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "m\N{U+00e1}n.",
    "t\N{U+00fd}s.",
    "mik.",
    "h\N{U+00f3}s.",
    "fr\N{U+00ed}.",
    "ley.",
    "sun.",
  ],
  day_format_narrow => [
    "M",
    "T",
    "M",
    "H",
    "F",
    "L",
    "S",
  ],
  day_format_wide => [
    "m\N{U+00e1}nadagur",
    "t\N{U+00fd}sdagur",
    "mikudagur",
    "h\N{U+00f3}sdagur",
    "fr\N{U+00ed}ggjadagur",
    "leygardagur",
    "sunnudagur",
  ],
  day_stand_alone_abbreviated => [
    "m\N{U+00e1}n",
    "t\N{U+00fd}s",
    "mik",
    "h\N{U+00f3}s",
    "fr\N{U+00ed}",
    "ley",
    "sun",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "M",
    "H",
    "F",
    "L",
    "S",
  ],
  day_stand_alone_wide => [
    "m\N{U+00e1}nadagur",
    "t\N{U+00fd}sdagur",
    "mikudagur",
    "h\N{U+00f3}sdagur",
    "fr\N{U+00ed}ggjadagur",
    "leygardagur",
    "sunnudagur",
  ],
  era_abbreviated => [
    "f.Kr.",
    "e.Kr.",
  ],
  era_narrow => [
    "fKr",
    "eKr",
  ],
  era_wide => [
    "fyri Krist",
    "eftir Krist",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Faroese",
  month_format_abbreviated => [
    "jan.",
    "feb.",
    "mar.",
    "apr.",
    "mai",
    "jun.",
    "jul.",
    "aug.",
    "sep.",
    "okt.",
    "nov.",
    "des.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "januar",
    "februar",
    "mars",
    "apr\N{U+00ed}l",
    "mai",
    "juni",
    "juli",
    "august",
    "september",
    "oktober",
    "november",
    "desember",
  ],
  month_stand_alone_abbreviated => [
    "jan",
    "feb",
    "mar",
    "apr",
    "mai",
    "jun",
    "jul",
    "aug",
    "sep",
    "okt",
    "nov",
    "des",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "januar",
    "februar",
    "mars",
    "apr\N{U+00ed}l",
    "mai",
    "juni",
    "juli",
    "august",
    "september",
    "oktober",
    "november",
    "desember",
  ],
  name => "Faroese",
  native_language => "f\N{U+00f8}royskt",
  native_name => "f\N{U+00f8}royskt",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "1. \N{U+00e1}rsfj.",
    "2. \N{U+00e1}rsfj.",
    "3. \N{U+00e1}rsfj.",
    "4. \N{U+00e1}rsfj.",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1. \N{U+00e1}rsfj\N{U+00f3}r\N{U+00f0}ingur",
    "2. \N{U+00e1}rsfj\N{U+00f3}r\N{U+00f0}ingur",
    "3. \N{U+00e1}rsfj\N{U+00f3}r\N{U+00f0}ingur",
    "4. \N{U+00e1}rsfj\N{U+00f3}r\N{U+00f0}ingur",
  ],
  quarter_stand_alone_abbreviated => [
    "1. \N{U+00e1}rsfj.",
    "2. \N{U+00e1}rsfj.",
    "3. \N{U+00e1}rsfj.",
    "4. \N{U+00e1}rsfj.",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1. \N{U+00e1}rsfj\N{U+00f3}r\N{U+00f0}ingur",
    "2. \N{U+00e1}rsfj\N{U+00f3}r\N{U+00f0}ingur",
    "3. \N{U+00e1}rsfj\N{U+00f3}r\N{U+00f0}ingur",
    "4. \N{U+00e1}rsfj\N{U+00f3}r\N{U+00f0}ingur",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 37,
}
